@@ -1,4 +1,5 @@
 def getdtapath():
+      """ path of Ptsdata"""
       import os
       import sys
       import PythonTsa 
@@ -7,8 +8,9 @@ def getdtapath():
          newdtapath=dtapath+'\\Ptsadata\\'
       elif sys.platform=='darwin':   
             newdtapath=dtapath+'/Ptsadata/'
+      elif sys.platform=='linux':   
+            newdtapath=dtapath+'/Ptsadata/'
       else:
-            print('Sorry, your platform should be Windows or Mac !')
+            print('Sorry, your platform should be Windows, Mac or Linux !')
             
-      return newdtapath
-      
+      return newdtapath
\ No newline at end of file
